@@ -4,11 +4,10 @@ import sh as sh
 
 
 class FaasClient:
-    def __init__(self, gateway_url, gateway_port, root_functions_folder, faas_config_file, username, password):
+    def __init__(self, gateway_url, gateway_port, root_functions_folder, username, password):
         self.__cli = sh.Command('faas-cli')
         self.endpoint = f'{gateway_url}:{gateway_port}'
         self.__root_functions_folder = root_functions_folder
-        self.__faas_config_file = faas_config_file
         self.__username = username
         self.__password = password
 
@@ -21,10 +20,6 @@ class FaasClient:
 
     def build(self, path_to_faas_configuration, function_name):
         configuration_filename = os.path.basename(path_to_faas_configuration)
-        print('path_to_faas_configuration: ', path_to_faas_configuration)
-        print('configuration_filename    : ', configuration_filename)
-        print('dirname                   : ',
-              os.path.dirname(path_to_faas_configuration))
         result = self.__cli(
             'build',
             '-f', configuration_filename,
@@ -53,11 +48,14 @@ class FaasClient:
 
 
 class FaasClientFactory:
-    def __init__(self, root_functions_folder, gateway_port, faas_config_file):
+    def __init__(self, root_functions_folder, gateway_port):
         self.__root_functions_folder = root_functions_folder
         self.__gateway_port = gateway_port
-        self.__faas_config_file = faas_config_file
 
     def create(self, gateway_url, username, password):
-        return FaasClient(gateway_url, self.__gateway_port, self.__root_functions_folder, self.__faas_config_file,
-                          username, password)
+        return FaasClient(
+            gateway_url,
+            self.__gateway_port,
+            self.__root_functions_folder,
+            username,
+            password)
